aboutsummaryrefslogtreecommitdiffstats
path: root/o3000_upgrade.c
diff options
context:
space:
mode:
authorPatrick Roth <roth@stettbacher.ch>2020-10-09 13:24:58 +0200
committerPatrick Roth <roth@stettbacher.ch>2020-10-09 13:24:58 +0200
commit6e04d6e2cc094aae7122627a96b35fb76038a17e (patch)
tree73e39de03aada04e2c6a87336b3bc9574945be04 /o3000_upgrade.c
parentDeleted comment lines. (diff)
downloado3000-driver-6e04d6e2cc094aae7122627a96b35fb76038a17e.tar.gz
o3000-driver-6e04d6e2cc094aae7122627a96b35fb76038a17e.zip
update --> upgrade , more checks added
Use firmware upgrade instead of update. The firmware update function does more sanity checks.
Diffstat (limited to 'o3000_upgrade.c')
-rw-r--r--o3000_upgrade.c10
1 files changed, 4 insertions, 6 deletions
diff --git a/o3000_upgrade.c b/o3000_upgrade.c
index 176be03..9e461e8 100644
--- a/o3000_upgrade.c
+++ b/o3000_upgrade.c
@@ -426,15 +426,13 @@ static enum cam_mode_t wait_for_bootloader_mode() {
}
/**
* Do firmware update of the device.
*
* Note: Parameters are already checked in o3000_firmware_update.
*
* @param data pointer to firmware update data
* @param data_len firmware update data lenght in bytes
* @return 0 on success, error code on failure
*/
-int firmware_update(unsigned char *data, int data_len) {
+int firmware_upgrade(unsigned char *data, int data_len) {
enum cam_mode_t cam_mode = CM_UNKNOWN;
@@ -426,15 +426,13 @@ static enum cam_mode_t wait_for_bootloader_mode() {
}
/**
- * Do firmware update of the device.
- *
- * Note: Parameters are already checked in o3000_firmware_update.
- *
- * @param data pointer to firmware update data
+ * Do firmware upgrade of the device.
+ *
+ * @param data pointer to firmware update data binary
* @param data_len firmware update data lenght in bytes
* @return 0 on success, error code on failure